@@ -1,8 +1,8 @@
 #!/bin/sh
-# $Id: testminiwget.sh,v 1.16 2018/01/16 01:01:05 nanard Exp $
+# $Id: testminiwget.sh,v 1.17 2019/12/23 23:35:41 nanard Exp $
 # vim: tabstop=4 shiftwidth=4 noexpandtab
 # project miniupnp : http://miniupnp.free.fr/
-# (c) 2011-2018 Thomas Bernard
+# (c) 2011-2019 Thomas Bernard
 #
 # test program for miniwget.c
 # is usually invoked by "make check"
@@ -23,12 +23,19 @@ DOWNLOADEDFILE="${TMPD}/downloadedfile"
 PORT=
 RET=0
 IPCONFIG=$(which ifconfig)
-if [ -z "$IPCONFIG" ] ; then
-	IPCONFIG="/sbin/ifconfig"
-fi
+IP=$(which ip)
+if [ "$IP" ] ; then
+	if ! $IP addr | grep inet6 ; then
+		HAVE_IPV6=no
+	fi
+else
+	if [ -z "$IPCONFIG" ] ; then
+		IPCONFIG="/sbin/ifconfig"
+	fi
 
-if ! $IPCONFIG -a | grep inet6 ; then
-	HAVE_IPV6=no
+	if ! $IPCONFIG -a | grep inet6 ; then
+		HAVE_IPV6=no
+	fi
 fi
 
 case "$HAVE_IPV6" in
